@@ -3,7 +3,7 @@ package POE::Component::OpenSSH;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moose;
 use Net::OpenSSH;
@@ -11,7 +11,7 @@ use POE::Component::Generic;
 
 has 'args'    => ( is => 'ro', isa => 'ArrayRef', default => sub { [] } );
 has 'options' => ( is => 'ro', isa => 'HashRef',  default => sub { {} } );
-has 'alias'   => ( is => 'ro', isa => 'Str',      default => ''         );
+has 'alias'   => ( is => 'ro', isa => 'Str',      default => q{}        );
 has 'debug'   => ( is => 'ro', isa => 'Bool',     default => 0          );
 has 'verbose' => ( is => 'ro', isa => 'Bool',     default => 0          );
 
@@ -26,11 +26,14 @@ sub _build_obj {
 
     my @optional = ( qw( alias debug verbose options ) );
     my $obj  = POE::Component::Generic->spawn(
-        package => 'Net::OpenSSH',
+        alias          => $self->alias,
+        package        => 'Net::OpenSSH',
         object_options => $self->args,
+        debug          => $self->debug,
+        verbose        => $self->verbose,
     );
 
-    $self->obj($obj);
+    return $obj;
 }
 
 1;
@@ -43,7 +46,7 @@ POE::Component::OpenSSH - Nonblocking SSH Component for POE using Net::OpenSSH
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -55,22 +58,63 @@ Need nonblocking SSH? You like Net::OpenSSH? Try out this stuff right here.
 
     # perhaps using verbose, debug?
     my $ssh = POE::Component::OpenSSH->new(
-        args    => [ $host, user => 'root', passwd => $pass ],
+        args    => [ ''root@host', passwd => $pass ],
         verbose => 1, # turns on POE::Component::Generic verbose
         debug   => 1, # turns on POE::Component::Generic debug
     );
-
-    # now set up events
-    $ssh->
     ...
 
+Here is an example using L<MooseX::POE>. If you know POE::Session, you can use that too:
+
+    package Runner;
+
+    use MooseX::POE;
+
+    has 'host' => ( is => 'ro', isa => 'Str', default => 'localhost' );
+    has 'user' => ( is => 'ro', isa => 'Str', default => 'root'      );
+    has 'pass' => ( is => 'ro', isa => 'Str', default => 'psss'      );
+    has 'cmd'  => ( is => 'ro', isa => 'Str', default => 'w'         );
+
+    sub START {
+        my $self = $_[OBJECT];
+        my $ssh  = POE::Component::OpenSSH->new(
+            args => [
+                $self->host,
+                user   => $self->user,
+                passwd => $self->passwd,
+            ],
+        );
+
+        # remember, $ssh is just POE::Component::OpenSSH
+        # you want the Net::OpenSSH object (or psuedo-object)
+        $ssh->obj->capture( { event => 'parse_cmd' }, $cmd );
+    }
+
+    event 'parse_cmd' => sub {
+        my ( $self, $output ) @_[ OBJECT, ARG1 ];
+        my $host = $self->host;
+        print "[$host]: $output";
+    };
+
+    package main;
+
+    my @machines = ( qw( server1 server2 server3 ) );
+
+    foreach my $machine (@machines) {
+        Runner->new(
+            host => $machine,
+            pass => 'my_super_pass',
+            cmd  => 'uname -a',
+        );
+    }
+
 =head1 DESCRIPTION
 
 This module allows you to use SSH (via L<Net::OpenSSH>) in a nonblocking manner.
 
 I kept having to write this small thing each time I needed nonblocking SSH in a project. I got tired of it so I wrote this instead.
 
-Why put the args in an "args" attribute instead of straight away attributes? Because Net::OpenSSH has a lot of options and they may collide with POE::Component::Generic's options, and I don't feel like maintaining the mess.
+You might ask 'why put the args in an "args" attribute instead of straight away attributes?' Because Net::OpenSSH has a lot of options and they may collide with POE::Component::Generic's options and I don't feel like maintaining the mess.
 
 It's on Github so you can patch it up if you want (I accept patches... and foodstamps).
 
@@ -122,8 +166,20 @@ L<http://search.cpan.org/dist/POE-Component-OpenSSH/>
 
 =back
 
+=head1 SEE ALSO
+
+If you have no idea what I'm doing (but you generally know what POE is), check these stuff:
+
+L<POE::Component::Generic>
+
+L<Net::OpenSSH>
+
+If you don't know POE at all, check L<POE>.
+
 =head1 DEPENDENCIES
 
+These are the actual dependencies, though I don't use Moose or POE directly but rather MooseX::POE.
+
 L<Net::OpenSSH>
 
 L<POE>
@@ -134,9 +190,10 @@ L<Moose>
 
 L<MooseX::POE>
 
+
 =head1 ACKNOWLEDGEMENTS
 
-All the people involved in the aforementioned projects.
+All the people involved in the aforementioned projects and the Perl community.
 
 =head1 COPYRIGHT & LICENSE
 
